/* Author: Derek O Reilly, Dundalk Institute of Technology, Ireland.       */
/* A CanvasGame that implements collision detection.                       */

let buttons = [];

class MultipleChoiceQuizCanvasGame extends CanvasGame
{
    constructor(jsonData)
    {
        super();
        this.jsonData = jsonData;

        /* If the current question has images on the buttons, they will be stored here. */
        this.currentImage = [new Image(), new Image(), new Image(), new Image()];

        this.score = 0;
        this.currentQuestion = 0;

        /* Load the first question */
        this.loadQuestion();
    }

    render()
    {
        super.render();
        
        for (let i = 0; i < buttons.length; i++)
        {
            if (buttons[i].isDisplayed())
            {
                buttons[i].render();
            }
        }
    }

    mousedown(x, y)
    {
        for (let i = 0; i < buttons.length; i++)
        {
            if (buttons[i].isDisplayed())
            {
                if (buttons[i].pointIsInsideBoundingRectangle(x, y))
                {
                    if (buttons[i].isThisTheCorrectAnswer())
                    {
                        this.score++;
                    }

                    this.currentQuestion++;

                    /* Check to see if all of the questions have been completed */
                    if (this.gameIsOver())
                    {
                        for (let i = 0; i < gameObjects.length; i++) /* stop all gameObjects from animating */
                        {
                            gameObjects[i].stopAndHide();
                        }
                        for (let i = 0; i < buttons.length; i++) /* stop all buttons from animating */
                        {
                            buttons[i].stopAndHide();
                        }

                        gameObjects[WIN_MESSAGE] = new StaticText("Your score is: " + this.score, 15, 260, "Times Roman", 75, "black");
                        gameObjects[WIN_MESSAGE].start(); /* render win message */
                    }
                    else /* Load the next question */
                    {
                        this.loadQuestion();
                    }

                    return; /* There is no need to test any other items in the for-loop */
                }
            }
        }
    }

    mousemove(x, y)
    {
        for (let i = 0; i < buttons.length; i++)
        {
            if (buttons[i].isDisplayed())
            {
                buttons[i].pointIsInsideBoundingRectangle(x, y); /* Used to highlight the button that the mouse is currently hovering over */
            }
        }
    }

    gameIsOver()
    {
        /* Test for end-of-game */
        return (this.currentQuestion === this.jsonData.questions.length);
    }

    loadQuestion()
    {
        /* Load the question from the json */
        gameObjects[QUESTION] = new StaticText(this.jsonData.questions[this.currentQuestion].question, STATIC_TEXT_CENTRE, 30, "Times Roman", 25, "red");
        gameObjects[QUESTION].start();

        /* Load the buttons from the json */
        for (let i = 0; i < this.jsonData.questions[this.currentQuestion].answers.length; i++)
        {
            /* Identify the button with the correct answer */
            let isCorrect = false;
            if (this.jsonData.questions[this.currentQuestion].correct === i + 1)
            {
                isCorrect = true;
            }

            /* Buttons might or might not have an image. We need to deal with both cases */
            if (this.jsonData.questions[this.currentQuestion].answers[i].image !== "")
            {
                this.currentImage[i].src = this.jsonData.questions[this.currentQuestion].answers[i].image;

                buttons[i] = new MultipleChoiceQuizButton(isCorrect, (canvas.width * 0.5) * (i % 2), (canvas.height * 0.1) + (canvas.height * 0.45) * (Math.floor(i / 2)), canvas.width * 0.5, canvas.height * 0.45, this.jsonData.questions[this.currentQuestion].answers[i].text, this.currentImage[i]);
            }
            else
            {
                buttons[i] = new MultipleChoiceQuizButton(isCorrect, (canvas.width * 0.5) * (i % 2), (canvas.height * 0.1) + (canvas.height * 0.45) * (Math.floor(i / 2)), canvas.width * 0.5, canvas.height * 0.45, this.jsonData.questions[this.currentQuestion].answers[i].text, null);
            }

            /* Display the button */
            buttons[i].start();
        }
    }
}